@@ -5,10 +5,14 @@ interval.ddd.dto
 This module provides DDD data transfer object base classes.
 """
 
-from dataclasses import dataclass
+from dataclasses import asdict, dataclass
+from typing import Any
 
 
 @dataclass
 class UseCaseDTO:
     """用例返回的数据传输对象"""
-    pass
+
+    def to_dict(self) -> dict[str, Any]:
+        """转换为字典"""
+        return asdict(self)
